DisjointGraphPairCombinator
===========================

.. currentmodule:: pykeen.datasets.ea.combination

.. autoclass:: DisjointGraphPairCombinator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DisjointGraphPairCombinator.process

   .. rubric:: Methods Documentation

   .. automethod:: process
